Learn R Programming

matrixTests (version 0.1.9.1)

ievora: iEVORA

Description

Epigenetic Variable Outliers for cancer Risk prediction Analysis

Usage

row_ievora(x, b, cutT = 0.05, cutBfdr = 0.001)

col_ievora(x, b, cutT = 0.05, cutBfdr = 0.001)

Value

a data.frame where each row contains result of the iEVORA algorithm for the corresponding row/column of x.

Each row contains the following information (in order):

1. obs.0 - number of observations in 0 group

2. obs.1 - number of observations in 1 group

3. obs.tot - number of total observations

4. mean.0 - mean of the 0 group

5. mean.1 - mean of the 1 group

6. mean.diff - mean difference (group1 - group0)

7. var.0 - variance of the 0 group

8. var.1 - variance of the 1 group

9. var.log2.ratio - log ratio of variances log2(var1/var0)

10. statistic.t - t.statistic of the t-test step

11. pvalue.t - raw p-value of the t-test step

12. statistic.bt - chsq.statistic of the bartlett test step

13. pvalue.bt - raw p-value of the Bartlett's test step

14. qvalue.bt - fdr-adjusted p-value of the Bartlett's test step

15. significant - indicator showing if the result was significant

16. rank - rank of the significant results (ordered by t.test p-value)

Arguments

x

numeric matrix

b

a binory vector specifying groups for each observation of x. Must contain two unique entries: one labeled "1" and another "0". If the vector is neither numeric nor logical the group appearing first is labeled "0" and the remaining one as "1".

cutT

cutoff threshold for the raw p-value of the t-test step. (default 0.05)

cutBfdr

cutoff threshold for the FDR-corrected p-value of the Bartlett's test step. (default 0.001)

Author

Karolis Koncevičius

Details

Measures differential variability between two groups. The algorithm has 2 steps: detecting difference in variance (Bartlett's test) and detecting difference in means (t-test). The second step is done to regularize the variability test which is overly sensitive to single outliers.

By default the result is considered significant if variability test produces a significant p-value (below selected threshold) after FDR correction and t-test returns a significant p-value without using the FDR correction.

The algorithm is mainly aimed at large DNA methylation data sets.

References

Andrew E Teschendorff et.al. DNA methylation outliers in normal breast tissue identify field defects that are enriched in cancer. Nature Communications 7, 10478 (2016) doi:10.1038/ncomms10478

See Also

row_bartlett, row_t_welch

Examples

Run this code
# perform iEVORA on iris dataset for setosa against all other groups
col_ievora(iris[,1:4], iris$Species=="setosa")

Run the code above in your browser using DataLab